@@ -120,6 +120,15 @@ def data_service(input, output):
         output['finish'] = True
         return
 
+    if action == '__init__':
+        result = {
+            'value': '__init__禁止访问！',
+            'status': 'err'
+        }
+        output['result'] = result
+        output['finish'] = True
+        return
+
     public_actions = getattr(g.app_core, 'public_actions', None)
     if public_actions is not None:
         if action not in public_actions:
@@ -218,6 +227,15 @@ def stream_service(input, output):
     bytestream = input.get('bytestream')
     threading.current_thread().request_info = input.get('request_info')
 
+    if action == '__init__':
+        result = {
+            'value': '__init__禁止访问！',
+            'status': 'err'
+        }
+        output['result'] = result
+        output['finish'] = True
+        return
+
     public_actions = getattr(g.app_core, 'public_actions', None)
     if public_actions is not None:
         if action not in public_actions:
